function gabor = computeGabor(img,param)
% Inputs:
% img - Image
% param - Gabor parameters
%
% Outputs:
% gabor - Gabor filter responses

if nargin < 2
  % Default parameters
  param.imageSize = 128;
  param.orientationsPerScale = [8 8 8 8];
  param.numberBlocks = 4;
  param.fc_prefilt = 4;
  param.G = createGabor(param.orientationsPerScale, param.imageSize);
else
  if ~isfield(param, 'G')
    param.G = createGabor(param.orientationsPerScale, param.imageSize);
  end
end

% Convert image to grayscale:
img = mean(single(img),3);

% resize and crop image to make it square
if (size(img,1)~=size(param.G,1)) || (size(img,2)~=size(param.G,2))
  img = imresizecrop(img, param.imageSize, 'bilinear');
end

% scale intensities to be in the range [0 255]
img = img-min(img(:));
img = 255*img/max(img(:));

% prefiltering: local contrast scaling
img = prefilt(img, param.fc_prefilt);

% remove mean to reduce boundary artifacts
img = img - mean(img(:));

% Perform FFT on image:
img = single(fft2(img)); 

% Compute Gabor filter responses:
Nfilters = size(param.G,3);
gabor = zeros(size(img,1),size(img,2),Nfilters,'single');
for n = 1:Nfilters
  gabor(:,:,n) = abs(ifft2(img.*param.G(:,:,n)));
end
