% Demo script for scene segmentation.  See README.txt for more details.

% Be sure to modify and run precompute.m on your database of images first
% before running this script.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CHANGE THE FOLLOWING TO POINT TO YOUR LOCAL LIBRARIES AND DATA
addpath /path/to/BerkeleyPB; % Berkeley PB library
addpath /path/to/GCv2p2_modified; % Modified GraphCuts library
HOMEGABOR = '/path/to/features'; % Pre-computed gabor+color features
HOMEIMAGES = '/path/to/images'; % (Optional) Images
DBMAT = '/path/to/DB.mat'; % Structure with list of images
GMAT = '/path/to/G.mat'; % Gist features
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load data structures:
load(DBMAT);
load(GMAT);

% Get image (assume image is 500x375 pixels):
img = imread('test.png');
imageSize = [size(img,1) size(img,2)];

% Run data-driven segmentation:
[S,compositeIndices] = DataDrivenSegmentation(img,G,[],[],DB,HOMEGABOR);

% Display segmentation:
outImg = overlaySegmentation(img,S,[0 0 0],12);
outImg = overlaySegmentation(outImg,S,[255 255 0],4);

figure;
imshow(outImg);

if exist('HOMEIMAGES','var')
  % Display image composites:
  Ncomp = 9; % Number of composites to return
  imgComposite = zeros(imageSize(1),imageSize(2),3,Ncomp,'uint8');
  for k = 1:size(compositeIndices,1)
    w = (S==k);
    stack = getImageStack(DB,HOMEIMAGES,compositeIndices(k,:),imageSize,Ncomp-1);
    imgComposite(repmat(w,[1 1 3 Ncomp])) = stack(repmat(w,[1 1 3 Ncomp]));
  end
  imgComposite(:,:,:,1) = img;
  for k = 1:Ncomp
    timg = overlaySegmentation(imgComposite(:,:,:,k),S,[0 0 0],12);
    imgComposite(:,:,:,k) = overlaySegmentation(timg,S,[255 255 0],4);
  end
  
  figure;
  montage(imgComposite);
end
