% Given a (large) collection of images, this script precomputes the
% required data structures that are used for the main algorithm.

% You will need the following variables for the main script (demo.m):
% HOMEIMAGES, DBMAT, GMAT, HOMEGABOR

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 1: Get list of images to compute.  We assume that all of the
% images are organized under a parent folder.  All sub-folders are stored
% as the 'folder' field in the structure.  The image names are stored as
% the 'filename' field in the structure.  As an example, suppose all of
% the images are stored in the folder '/path/to/images/here/*.jpg'.
% Then, the following can be run.
HOMEIMAGES = '/path/to/images';
DBMAT = '/path/to/DB.mat';

folder = 'here';
f = dir(fullfile(HOMEIMAGES,folder,'*.jpg'));
DB = [];
for i = 1:length(f)
  DB(i).folder = folder;
  DB(i).filename = f(i).name;
end

save(DBMAT,'DB');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 2: Compute gist features.
GMAT = '/path/to/G.mat';

for i = 1:length(DB)
  img = imread(fullfile(HOMEIMAGES,DB(i).folder,DB(i).filename));
  img = imresize(img,imageSize,'bicubic');
  g = getfield(runGistIm(img),'D');
  if i==1
    G = zeros(length(g),length(DB),'single');
  end
  G(:,i) = g;
end

save(GMAT,'G');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 3: Compute Gabor + color features.
HOMEGABOR = '/path/to/features'; % Set this to where you want the
                                 % features stored.

imageSize = [375 500];
allGaborCellSize = 8; % Gabor block size
param.orientationsPerScale = [8 8 8 8];
param.fc_prefilt = 4;
param.imageSize = imageSize;
param.G = createGabor(param.orientationsPerScale,param.imageSize);

for i = 1:length(DB)
  display(sprintf('%d out of %d',i,length(DB)));
  img = imread(fullfile(HOMEIMAGES,DB(i).folder,DB(i).filename));
  img = imresize(img,imageSize,'bicubic');
  gabor = single(gridResponse(computeGabor(img,param),allGaborCellSize));
  gabor = addColorFeatures(img,gabor);
  if ~exist(fullfile(HOMEGABOR,DB(i).folder),'dir')
    mkdir(fullfile(HOMEGABOR,DB(i).folder));
  end
  save(fullfile(HOMEGABOR,DB(i).folder,[DB(i).filename '.mat']),'gabor');
end
