function rho = rankCorrelation(r1,r2)
% Compute Spearman's rank correlation coefficient.
%
% Inputs:
% r1
% r2
%
% Outputs:
% rho

n = length(r1);

if length(r2) ~= n
  error('Lengths must be the same');
  return;
end

if (length(unique(r1))~=n) || (length(unique(r2))~=n)
  % Use Pearson correlation since there are ties:
  rho = (n*sum(r1.*r2)-sum(r1)*sum(r2))/sqrt(n*sum(r1.^2)-sum(r1)^2)/sqrt(n*sum(r2.^2)-sum(r2)^2);
else
  % Use Spearman:
  rho = 1 - 6*sum((r1-r2).^2)/n/(n^2-1);
end
